@@ -17,6 +17,7 @@ class WordLangTuple;
 
 /**
  * Base class of all spell checker implementations.
+ * The class can be instantiated but will have no functionality.
  */
 class SpellBase {
 public:
@@ -34,22 +35,22 @@ public:
 	virtual ~SpellBase() {}
 
 	/// return true if the spellchecker instance still exists
-	virtual bool alive() = 0;
+	virtual bool alive();
 
 	/// check the given word of the given lang code and return the result
-	virtual enum Result check(WordLangTuple const &) = 0;
+	virtual enum Result check(WordLangTuple const &);
 
 	/// insert the given word into the personal dictionary
-	virtual void insert(WordLangTuple const &) = 0;
+	virtual void insert(WordLangTuple const &);
 
 	/// accept the given word temporarily
-	virtual void accept(WordLangTuple const &) = 0;
+	virtual void accept(WordLangTuple const &);
 
 	/// return the next near miss after a MISSED result
-	virtual string const nextMiss() = 0;
+	virtual string const nextMiss();
 
 	/// give an error message on messy exit
-	virtual string const error() = 0;
+	virtual string const error();
 
 };
 
