@@ -13,10 +13,6 @@
 #ifndef BUFFER_H
 #define BUFFER_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "LString.h"
 #include "undo.h"
 #include "support/limited_stack.h"
@@ -229,7 +225,11 @@ public:
 	void setFileName(string const & newfile);
 
 	/// Name of the document's parent
-	void setParentName(string const &);
+	void setParentName(string const & = string());
+
+	/// Get the document's master (or \c this if this is not a
+	//child document)
+	Buffer const * getMasterBuffer() const;
 
 	/// Is buffer read-only?
 	bool isReadonly() const;
