@@ -13,10 +13,6 @@
 #ifndef LYXVIEW_H
 #define LYXVIEW_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "LString.h"
 
 #include "support/types.h"
