@@ -1,25 +1,18 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
- *
- *           LyX, The Document Processor
- *
- *           Copyright 2001 The LyX Team.
- *
- * ======================================================
- *
+/**
  * \file ControlBibitem.h
- * \author John Levon, moz@compsoc.man.ac.uk
- * \author Angus Leeming <a.leeming@ic.ac.uk>
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author John Levon
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef CONTROLBIBITEM_H
 #define CONTROLBIBITEM_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "ControlCommand.h"
 
 /** A controller for Bibitem dialogs.
@@ -28,7 +21,6 @@ class ControlBibitem : public ControlCommand {
 public:
 	///
 	ControlBibitem(LyXView &, Dialogs &);
-
 private:
 	/// Dispatch the changed parameters to the kernel.
 	virtual void applyParamsToInset();
