@@ -1,27 +1,22 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
- *
- *           LyX, The Document Processor
- *
- *          Copyright 2001 The LyX Team.
- *
- *======================================================
- *
+/**
  * \file ControlFloat.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author unknown
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef CONTROLFLOAT_H
 #define CONTROLFLOAT_H
 
-#include <vector>
-
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "ControlInset.h"
 
+// needed to instatiate inset->hideDialog in ControlInset
+#include "insets/insetfloat.h"
+
 class InsetFloat;
 
 ///
@@ -33,14 +28,14 @@ struct FloatParams {
 	///
 	string placement;
 	///
-	bool allow_here_definitely;
+	bool wide;
 };
 
 
 inline
 bool operator==(FloatParams const & p1, FloatParams const & p2)
 {
-	return p1.placement == p2.placement && p1.allow_here_definitely == p2.allow_here_definitely;
+	return p1.placement == p2.placement && p1.wide == p2.wide;
 }
 
 
