@@ -16,10 +16,6 @@
 
 #include <sigc++/sigc++.h>
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 /**
  * This class executes the callback when the timeout expires
  * using Gnome mechanisms
