@@ -12,10 +12,6 @@
 #ifndef QERT_H
 #define QERT_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "Qt2Base.h"
 
 class ControlERT;
