@@ -12,10 +12,6 @@
 #ifndef QINCLUDE_H
 #define QINCLUDE_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "Qt2Base.h"
 
 class ControlInclude;
