@@ -12,10 +12,6 @@
 #ifndef QMATH_H
 #define QMATH_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "LString.h"
 
 class QMathDialog;
