@@ -1,31 +1,32 @@
+// -*- C++ -*-
 /**
  * \file QRef.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef QREF_H
 #define QREF_H
 
-#include <config.h>
+#include "Qt2Base.h"
 #include <vector>
 #include "LString.h"
 
-#include "Qt2Base.h"
-
 class ControlRef;
 class QRefDialog;
 
-class QRef :
-	public Qt2CB<ControlRef, Qt2DB<QRefDialog> >
+
+class QRef
+	: public Qt2CB<ControlRef, Qt2DB<QRefDialog> >
 {
+public:
 	friend class QRefDialog;
 
-public:
-	QRef(ControlRef & c);
-
+	QRef();
 private:
 	/// apply changes
 	virtual void apply();
