@@ -12,10 +12,6 @@
 #ifndef QT2BASE_H
 #define QT2BASE_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "ViewBase.h"
 #include <boost/scoped_ptr.hpp>
 
@@ -174,14 +170,14 @@ Qt2CB<Controller, Base>::Qt2CB(QString const & t)
 template <class Controller, class Base>
 Controller & Qt2CB<Controller, Base>::controller()
 {
-	return static_cast<Controller &>(getController());
+	return static_cast<Controller &>(this->getController());
 }
 
 
 template <class Controller, class Base>
 Controller const & Qt2CB<Controller, Base>::controller() const
 {
-	return static_cast<Controller const &>(getController());
+	return static_cast<Controller const &>(this->getController());
 }
 
 
