@@ -1,32 +1,29 @@
 // -*- C++ -*-
 /**
  * \file FormInclude.h
- * Copyright 2001 the LyX Team
- * See the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author Alejandro Aguilar Sierra
- * \author John Levon, moz@compsoc.man.ac.uk
- * \author Angus Leeming, a.leeming@ic.ac.uk
+ * \author John Levon
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 #ifndef FORMINCLUDE_H
 #define FORMINCLUDE_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "FormBase.h"
 
 class ControlInclude;
-struct FD_form_include;
+struct FD_include;
 
 /** This class provides an XForms implementation of the Include Dialog.
  */
-class FormInclude : public FormCB<ControlInclude, FormDB<FD_form_include> > {
+class FormInclude : public FormCB<ControlInclude, FormDB<FD_include> > {
 public:
 	///
-	FormInclude(ControlInclude &);
-
+	FormInclude();
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -36,9 +33,6 @@ private:
 	virtual void update();
 	/// Filter the inputs on callback from xforms
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
-
-	/// Fdesign generated method
-	FD_form_include * build_include();
 };
 
 #endif
