@@ -1,31 +1,29 @@
 // -*- C++ -*-
 /**
  * \file xforms/FormToc.h
- * Copyright 2000-2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Angus Leeming, a.leeming@ic.ac.uk
+ * \author Angus Leeming
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef FORMTOC_H
 #define FORMTOC_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "FormBase.h"
-#include "buffer.h"
+#include "toc.h"
 
 class ControlToc;
-struct FD_form_toc;
+struct FD_toc;
 
 /** This class provides an XForms implementation of the FormToc Dialog.
  */
-class FormToc : public FormCB<ControlToc, FormDB<FD_form_toc> > {
+class FormToc : public FormCB<ControlToc, FormDB<FD_toc> > {
 public:
 	///
-	FormToc(ControlToc &);
+	FormToc();
 private:
 	/// not needed
 	virtual void apply() {}
@@ -41,11 +39,8 @@ private:
 	///
 	void updateContents();
 
-	/// Fdesign generated method
-	FD_form_toc * build_toc();
-
 	///
-	Buffer::SingleList toclist_;
+	toc::Toc toc_;
 };
 
 #endif // FORMTOC_H
