@@ -12,10 +12,6 @@
 #ifndef INSET_PARENT_H
 #define INSET_PARENT_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "insetcommand.h"
 
 class Buffer;
