@@ -12,10 +12,6 @@
 #ifndef LYXRC_H
 #define LYXRC_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "bufferparams.h" // Just to get the enum BufferParams::PAPER_SIZE (sic)
 #include "graphics/GraphicsTypes.h"
 
@@ -127,6 +123,9 @@ enum LyXRCTags {
 #ifdef USE_PSPELL
 	RC_USE_PSPELL,
 #endif
+ 	RC_CYGWIN_PATH_FIX,
+	RC_TEX_ALLOWS_SPACES,
+	RC_PATH_PREFIX,
 	RC_LAST
 };
 
@@ -357,6 +356,14 @@ enum LyXRCTags {
 	bool preview_hashed_labels;
 	///
 	float preview_scale_factor;
+	///
+	bool cygwin_path_fix;
+	/// True if the TeX engine can handle file names containing spaces
+	bool tex_allows_spaces;
+	/** Prepend paths to the PATH environment variable.
+	 *  The string is input, stored and output in native format.
+	 */
+	std::string path_prefix;
 
 private:
 	/// Is a bind file already (or currently) read?
