@@ -12,10 +12,6 @@
 #ifndef LYXROW_H
 #define LYXROW_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "support/types.h"
 
 class Paragraph;
