@@ -12,10 +12,6 @@
 #ifndef LYXSERVER_H
 #define LYXSERVER_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "LString.h"
 
 #include <boost/signals/trackable.hpp>
