@@ -4,10 +4,6 @@
 
 #include "math_gridinset.h"
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 /**
  * Inset for things like [pbvV]matrix, psmatrix etc
  *
@@ -37,7 +33,8 @@ public:
 	void write(WriteStream & os) const;
 	///
 	void normalize(NormalStream &) const;
-
+	///
+	void validate(LaTeXFeatures & features) const;
 private:
 	///
 	char const * name_left() const;
