@@ -4,10 +4,13 @@
 
 #include "math_gridinset.h"
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
+/**
+ * Inset for things like \begin{array}...\end{array}
+ *
+ * \author Andr Pnitz
+ *
+ * Full author contact details are available in file CREDITS
+ */
 
 class MathArrayInset : public MathGridInset {
 public:
@@ -23,9 +26,13 @@ public:
 	///
 	MathInset * clone() const;
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & mi) const;
+	///
+	void draw(MathPainterInfo & pi, int x, int y) const;
 	///
 	MathArrayInset * asArrayInset() { return this; }
+	///
+	MathArrayInset const * asArrayInset() const { return this; }
 
 	///
 	void write(WriteStream & os) const;
@@ -33,7 +40,8 @@ public:
 	void normalize(NormalStream &) const;
 	///
 	void maplize(MapleStream &) const;
-
+	///
+	void validate(LaTeXFeatures & features) const;
 private:
 	///
 	string name_;
