@@ -17,10 +17,6 @@
 #include "lyxlib.h"
 #include <boost/utility.hpp>
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 
 /**
  * Path - utility closs for stackable working directories
